birth

# XMLRésuméLibrary: User Guide

awards | Element Reference | bookTitle

## Name

birth — Container for information about a person's birth

## Synopsis

### Content Model

    (date)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `birth` element contains a single `date` that specifies when a person was born.

### Parents

`birth` may be contained in these elements: `header`

## Examples

    <header>
      <name>
        <firstname>Scotty</firstname>
        <surname>O'Reilly</surname>
      </name>
      <birth>
        <date>
          <dayOfMonth>17</dayOfMonth>
          <month>March</month>
          <year>1931</year>
        </date>
      </birth>
    </header>

    <header>
      <name>
        <firstname>Josè</firstname>
        <middlenames>Luis Miguel</middlenames>
        <surname>Domingo</surname>
      </name>
      <birth>
        <date>
          <dayOfMonth>23</dayOfMonth>
          <month>Mayo</month>
          <year>1834</year>
        </date>
      </birth>
    </header>

awards | Element Reference | bookTitle